cytoflow.operations package
===========================

Subpackages
-----------

.. toctree::

    cytoflow.operations.logicle_ext

Submodules
----------

cytoflow.operations.hlog module
-------------------------------

.. automodule:: cytoflow.operations.hlog
    :members:
    :undoc-members:
    :show-inheritance:

cytoflow.operations.i_operation module
--------------------------------------

.. automodule:: cytoflow.operations.i_operation
    :members:
    :undoc-members:
    :show-inheritance:

cytoflow.operations.logicle module
----------------------------------

.. automodule:: cytoflow.operations.logicle
    :members:
    :undoc-members:
    :show-inheritance:

cytoflow.operations.threshold module
------------------------------------

.. automodule:: cytoflow.operations.threshold
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: cytoflow.operations
    :members:
    :undoc-members:
    :show-inheritance:
